// provided by Aaron Skonnard (http://staff.develop.com/aarons)

using System;
using System.Xml;
using System.Text;
using System.IO;

class WritingXmlExamples
{
	static void GenerateXTWRaw()
	{
		// instantiate XmlTextWriter over file stream using UTF-8 
		XmlTextWriter tw = new XmlTextWriter("aaron1.xml", Encoding.UTF8);
		// specify serialization details
		tw.Formatting = Formatting.Indented;
		tw.Indentation = 5;
		tw.QuoteChar = '\'';
		// generate logical stream of nodes through sequence of method calls
		tw.WriteStartDocument();
		tw.WriteComment(" Aaron Skonnard's name structure ");
		tw.WriteStartElement("x", "name", "http://example.org/name");
		tw.WriteStartElement("first");
		tw.WriteString("Aaron");
		tw.WriteEndElement();
		tw.WriteStartElement("last");
		tw.WriteString("Skonnard");
		tw.WriteEndElement();
		tw.WriteEndElement();
		tw.WriteEndDocument();
		// close the stream
		tw.Close();
	}

	static void GenerateXTWWriteElementString()
	{
		XmlTextWriter tw = new XmlTextWriter("aaron2.xml", Encoding.UTF8);
		tw.Formatting = Formatting.Indented;
		tw.WriteStartDocument();
		tw.WriteComment(" Aaron Skonnard's name structure ");
		tw.WriteStartElement("x", "name", "http://example.org/name");
		tw.WriteElementString("first", "Aaron");
		tw.WriteElementString("last", "Skonnard");
		tw.WriteEndElement();
		tw.WriteEndDocument();
		tw.Close();
	}

	static void GenerateXTWAttributes()
	{
		XmlTextWriter tw = new XmlTextWriter("aaron3.xml", Encoding.UTF8);
		tw.Formatting = Formatting.Indented;
		tw.WriteStartDocument();
		tw.WriteComment(" Aaron Skonnard's name structure ");
		tw.WriteStartElement("x", "name", "http://example.org/name");
		tw.WriteAttributeString("", "ssnum", "", "555-55-1212");
		tw.WriteAttributeString("", "key", "", "43532325");
		tw.WriteElementString("first", "Aaron");
		tw.WriteElementString("last", "Skonnard");
		tw.WriteEndElement();
		tw.WriteEndDocument();
		tw.Close();
	}
	
	static void GenerateXTWQNames()
	{
		XmlTextWriter tw = new XmlTextWriter("aaron4.xml", Encoding.UTF8);
		tw.Formatting = Formatting.Indented;
		tw.WriteStartDocument();
		tw.WriteComment(" Aaron Skonnard's name structure ");
		tw.WriteStartElement("x", "name", "http://example.org/name");
		tw.WriteAttributeString("", "ssnum", "", "555-55-1212");
		tw.WriteAttributeString("", "dl", "", "43532325");
		tw.WriteElementString("first", "Aaron");
		tw.WriteElementString("last", "Skonnard");
		tw.WriteStartElement("title");
		tw.WriteQualifiedName("Mr", "http://example.org/name");
		tw.WriteEndElement();
		//tw.WriteElementString("title", tw.LookupPrefix("http://example.org/name")+":"+"Mr");
		tw.WriteEndElement();
		tw.WriteEndDocument();
		tw.Close();
	}

	static void GenerateDOM()
	{
		XmlDocument doc = new XmlDocument();
		XmlNode comment, name, first, last;
		comment = doc.CreateComment(" Aaron Skonnard's name structure ");
		doc.AppendChild(comment);
		name = doc.CreateElement("x", "name", "http://example.org/name");
		doc.AppendChild(name);
		first = doc.CreateElement("first");
		first.InnerText = "Aaron";
		name.AppendChild(first);
		last = doc.CreateElement("last");
		last.InnerText = "Skonnard";
		name.AppendChild(last);
		// save tree out as string
		Console.WriteLine(doc.InnerXml);
		// save tree to TextWriter
		doc.Save(Console.Out);
		// save tree to XmlTextWriter
		XmlTextWriter tw = new XmlTextWriter("aaron5.xml", Encoding.UTF8);
		tw.Formatting = Formatting.Indented;
		doc.Save(tw);
	}

	static void Main(string[] args)
	{
		GenerateXTWRaw();
		GenerateXTWWriteElementString();
		GenerateXTWAttributes();
		GenerateXTWQNames();
		GenerateDOM();
	}
}
